@@ -63,6 +63,7 @@ def run(args, parser):
     if args.suffix is None and\
        args.dir_include is None and args.dir_exclude is None and args.file_include is None and\
        args.file_exclude is None:
+        print("simple version...")
 
         if args.match_patten_arg is None:
             bf = BatchPathMatch(args.path, patten=args.match_patten, trans=args.translate,
@@ -106,6 +107,9 @@ def run(args, parser):
     else:
         fdir = bf.file_dir
 
+    if args.reverse:
+        fdir.reverse()
+
     num = len(fdir)
 
     if args.not_print is True:
@@ -144,6 +148,7 @@ class CLICommand:
                             default="paths.temp")
         parser.add_argument('-np', '--not_print', help='not print.', action="store_false")
         parser.add_argument('-parent', '--parent', help='with parent or not.', action="store_true")
+        parser.add_argument('-r', '--reverse', help='reverse the list.', action="store_true")
 
     @staticmethod
     def parse_args(parser):
